#!/usr/bin/env python

'''Partadm sets partition attributes in the scheduler'''
__revision__ = '$Revision: 1.5 $'

from sss.ssslib import comm_lib
from sys import argv
from getopt import getopt, GetoptError
from elementtree.ElementTree import Element, SubElement, XML, tostring

helpmsg = '''Usage: partadm.py [-a] [-d] [-s size] part1 part2 (add or del)
Usage: partadm.py [-start|-stop] part1 part2 (online or offline)
Usage: partadm.py --queue=queue1:queue2 part1 part2
Must supply one of -a or -d -start or -stop or --queue'''

if __name__ == '__main__':
    try:
        (opts, args) = getopt(argv[1:], 'adls:', ['-start', '-stop', 'queue='])
    except GetoptError, msg:
        print msg
        print helpmsg
        raise SystemExit, 1
    if '-a' in argv:
        msg = Element("AddPartition")
        try:
            [size] = [opt[1] for opt in opts if opt[0] == '-s']
        except:
            print "Must supply partition size with -s"
            raise SystemExit, 1
        for partname in args:
            SubElement(msg, "Partition", name=partname, size=size, admin='offline', queue='default')
    elif '-d' in argv:
        msg = Element('DelPartition')
        for partname in args:
            SubElement(msg, "Partition", name=partname)
    elif '-start' in argv:
        msg = Element('Online')
        for partname in args:
            SubElement(msg, "Partition", name=partname)
    elif '-stop' in argv:
        msg = Element('Offline')
        for partname in args:
            SubElement(msg, "Partition", name=partname)
    elif '-l' in argv:
        msg = Element('GetPartition')
        SubElement(msg, 'Partition', name='*', size='*', state='*', admin='*', queue='*')
    elif '--queue' in [opt for (opt, arg)  in opts]:
        queue = [arg for (opt, arg) in opts if opt == '--queue'][0]
        msg = Element("SetQueue", queue=queue)
        for partname in args:
            SubElement(msg, 'Partition', name=partname)
    else:
        print helpmsg
        raise SystemExit, 1

    comm = comm_lib()
    handle = comm.ClientInit('scheduler')
    comm.SendMessage(handle, tostring(msg))
    resp = comm.RecvMessage(handle)
    comm.ClientClose(handle)

    if '-l' in argv:
        pinfo = XML(resp)
        for part in pinfo.findall('Partition'):
            print tostring(part)
    else:
        print resp
            
        
